@@ -22,7 +22,6 @@
 #include <QTemporaryDir>
 #include <QTemporaryFile>
 
-#include <kwidgetsaddons_version.h>
 #include <KPluginMetaData>
 #include <KActionCollection>
 #include <KJobWidgets>
@@ -51,23 +50,15 @@
 #include "komparesplitter.h"
 #include "kompareview.h"
 
-using namespace Diff2;
+using namespace KompareDiff2;
 
 ViewSettings* KomparePart::m_viewSettings = nullptr;
-DiffSettings* KomparePart::m_diffSettings = nullptr;
+KompareDiff2::DiffSettings* KomparePart::m_diffSettings = nullptr;
 
 KomparePart::KomparePart(QWidget* parentWidget, QObject* parent, const KPluginMetaData& metaData, Modus modus) :
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     KParts::ReadWritePart(parent, metaData),
-#else
-    KParts::ReadWritePart(parent),
-#endif
     m_info()
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    setMetaData(metaData);
-#endif
-
     // set our XML-UI resource file
     setXMLFile(QStringLiteral("komparepartui.rc"));
 
@@ -75,7 +66,7 @@ KomparePart::KomparePart(QWidget* parentWidget, QObject* parent, const KPluginMe
         m_viewSettings = new ViewSettings(nullptr);
     }
     if (!m_diffSettings) {
-        m_diffSettings = new DiffSettings(nullptr);
+        m_diffSettings = new KompareDiff2::DiffSettings();
     }
 
     readProperties(KSharedConfig::openConfig().data());
@@ -88,74 +79,74 @@ KomparePart::KomparePart(QWidget* parentWidget, QObject* parent, const KPluginMe
     m_splitter = m_view->splitter();
 
     // This creates the "Model creator" and connects the signals and slots
-    m_modelList = new Diff2::KompareModelList(m_diffSettings, this, "komparemodellist" , (modus == ReadWriteModus));
+    m_modelList = new KompareDiff2::ModelList(m_diffSettings, this, (modus == ReadWriteModus));
 
     const auto modelListActions = m_modelList->actionCollection()->actions();
     for (QAction* action : modelListActions) {
         actionCollection()->addAction(action->objectName(), action);
     }
-    connect(m_modelList, &KompareModelList::status,
+    connect(m_modelList, &ModelList::status,
             this, &KomparePart::slotSetStatus);
-    connect(m_modelList, &KompareModelList::setStatusBarModelInfo,
+    connect(m_modelList, &ModelList::setStatusBarModelInfo,
             this, &KomparePart::setStatusBarModelInfo);
-    connect(m_modelList, &KompareModelList::error,
+    connect(m_modelList, &ModelList::error,
             this, &KomparePart::slotShowError);
-    connect(m_modelList, &KompareModelList::applyAllDifferences,
+    connect(m_modelList, &ModelList::applyAllDifferences,
             this, &KomparePart::updateActions);
-    connect(m_modelList, static_cast<void(KompareModelList::*)(bool)>(&KompareModelList::applyDifference),
+    connect(m_modelList, static_cast<void(ModelList::*)(bool)>(&ModelList::applyDifference),
             this, &KomparePart::updateActions);
-    connect(m_modelList, &KompareModelList::applyAllDifferences,
+    connect(m_modelList, &ModelList::applyAllDifferences,
             this, &KomparePart::appliedChanged);
-    connect(m_modelList, static_cast<void(KompareModelList::*)(bool)>(&KompareModelList::applyDifference),
+    connect(m_modelList, static_cast<void(ModelList::*)(bool)>(&ModelList::applyDifference),
             this, &KomparePart::appliedChanged);
-    connect(m_modelList, &KompareModelList::updateActions, this, &KomparePart::updateActions);
+    connect(m_modelList, &ModelList::updateActions, this, &KomparePart::updateActions);
 
     // This is the stuff to connect the "interface" of the kompare part to the model inside
-    connect(m_modelList, &KompareModelList::modelsChanged,
+    connect(m_modelList, &ModelList::modelsChanged,
             this, &KomparePart::modelsChanged);
 
-    typedef void(KompareModelList::*void_KompareModelList_argModelDiff)(const DiffModel*, const Difference*);
-    typedef void(KompareModelList::*void_KompareModelList_argDiffBool)(const Difference*, bool);
+    typedef void(ModelList::*void_ModelList_argModelDiff)(const DiffModel*, const Difference*);
+    typedef void(ModelList::*void_ModelList_argDiffBool)(const Difference*, bool);
     typedef void(KompareSplitter::*void_KompareSplitter_argModelDiff)(const DiffModel*, const Difference*);
     typedef void(KompareSplitter::*void_KompareSplitter_argDiffBool)(const Difference*, bool);
     typedef void(KomparePart::*void_KomparePart_argModelDiff)(const DiffModel*, const Difference*);
     typedef void(KomparePart::*void_KomparePart_argDiffBool)(const Difference*, bool);
-    connect(m_modelList, static_cast<void_KompareModelList_argModelDiff>(&KompareModelList::setSelection),
+    connect(m_modelList, static_cast<void_ModelList_argModelDiff>(&ModelList::setSelection),
             this, static_cast<void_KomparePart_argModelDiff>(&KomparePart::setSelection));
     connect(this, static_cast<void_KomparePart_argModelDiff>(&KomparePart::selectionChanged),
-            m_modelList, static_cast<void_KompareModelList_argModelDiff>(&KompareModelList::slotSelectionChanged));
+            m_modelList, static_cast<void_ModelList_argModelDiff>(&ModelList::slotSelectionChanged));
 
-    connect(m_modelList, static_cast<void(KompareModelList::*)(const Difference*)>(&KompareModelList::setSelection),
+    connect(m_modelList, static_cast<void(ModelList::*)(const Difference*)>(&ModelList::setSelection),
             this, static_cast<void(KomparePart::*)(const Difference*)>(&KomparePart::setSelection));
     connect(this, static_cast<void(KomparePart::*)(const Difference*)>(&KomparePart::selectionChanged),
-            m_modelList, static_cast<void(KompareModelList::*)(const Difference*)>(&KompareModelList::slotSelectionChanged));
+            m_modelList, static_cast<void(ModelList::*)(const Difference*)>(&ModelList::slotSelectionChanged));
 
-    connect(m_modelList, static_cast<void(KompareModelList::*)(bool)>(&KompareModelList::applyDifference),
+    connect(m_modelList, static_cast<void(ModelList::*)(bool)>(&ModelList::applyDifference),
             this, static_cast<void(KomparePart::*)(bool)>(&KomparePart::applyDifference));
-    connect(m_modelList, &KompareModelList::applyAllDifferences,
+    connect(m_modelList, &ModelList::applyAllDifferences,
             this, &KomparePart::applyAllDifferences);
-    connect(m_modelList, static_cast<void_KompareModelList_argDiffBool>(&KompareModelList::applyDifference),
+    connect(m_modelList, static_cast<void_ModelList_argDiffBool>(&ModelList::applyDifference),
             this, static_cast<void_KomparePart_argDiffBool>(&KomparePart::applyDifference));
-    connect(m_modelList, &KompareModelList::diffString,
+    connect(m_modelList, &ModelList::diffString,
             this, &KomparePart::diffString);
 
-    connect(this, &KomparePart::kompareInfo, m_modelList, &KompareModelList::slotKompareInfo);
+    connect(this, &KomparePart::kompareInfo, m_modelList, &ModelList::slotKompareInfo);
 
     // Here we connect the splitter to the modellist
-    connect(m_modelList, static_cast<void_KompareModelList_argModelDiff>(&KompareModelList::setSelection),
+    connect(m_modelList, static_cast<void_ModelList_argModelDiff>(&ModelList::setSelection),
             m_splitter,  static_cast<void_KompareSplitter_argModelDiff>(&KompareSplitter::slotSetSelection));
-//     connect(m_splitter,  SIGNAL(selectionChanged(const Diff2::Difference*,const Diff2::Difference*)),
-//             m_modelList, SLOT(slotSelectionChanged(const Diff2::Difference*,const Diff2::Difference*)));
-    connect(m_modelList, static_cast<void(KompareModelList::*)(const Difference*)>(&KompareModelList::setSelection),
+//     connect(m_splitter,  SIGNAL(selectionChanged(const KompareDiff2::Difference*,const KompareDiff2::Difference*)),
+//             m_modelList, SLOT(slotSelectionChanged(const KompareDiff2::Difference*,const KompareDiff2::Difference*)));
+    connect(m_modelList, static_cast<void(ModelList::*)(const Difference*)>(&ModelList::setSelection),
             m_splitter,  static_cast<void(KompareSplitter::*)(const Difference*)>(&KompareSplitter::slotSetSelection));
     connect(m_splitter,  static_cast<void(KompareSplitter::*)(const Difference*)>(&KompareSplitter::selectionChanged),
-            m_modelList, static_cast<void(KompareModelList::*)(const Difference*)>(&KompareModelList::slotSelectionChanged));
+            m_modelList, static_cast<void(ModelList::*)(const Difference*)>(&ModelList::slotSelectionChanged));
 
-    connect(m_modelList, static_cast<void(KompareModelList::*)(bool)>(&KompareModelList::applyDifference),
+    connect(m_modelList, static_cast<void(ModelList::*)(bool)>(&ModelList::applyDifference),
             m_splitter, static_cast<void(KompareSplitter::*)(bool)>(&KompareSplitter::slotApplyDifference));
-    connect(m_modelList, &KompareModelList::applyAllDifferences,
+    connect(m_modelList, &ModelList::applyAllDifferences,
             m_splitter, &KompareSplitter::slotApplyAllDifferences);
-    connect(m_modelList, static_cast<void_KompareModelList_argDiffBool>(&KompareModelList::applyDifference),
+    connect(m_modelList, static_cast<void_ModelList_argDiffBool>(&ModelList::applyDifference),
             m_splitter, static_cast<void_KompareSplitter_argDiffBool>(&KompareSplitter::slotApplyDifference));
     connect(this, &KomparePart::configChanged, m_splitter, &KompareSplitter::configChanged);
 
@@ -208,9 +199,9 @@ void KomparePart::setupActions(Modus modus)
 void KomparePart::updateActions()
 {
     if (m_saveAll) m_saveAll->setEnabled(m_modelList->hasUnsavedChanges());
-    if (m_saveDiff) m_saveDiff->setEnabled(m_modelList->mode() == Kompare::ComparingFiles || m_modelList->mode() == Kompare::ComparingDirs);
-    if (m_swap) m_swap->setEnabled(m_modelList->mode() == Kompare::ComparingFiles || m_modelList->mode() == Kompare::ComparingDirs);
-    m_diffRefresh->setEnabled(m_modelList->mode() == Kompare::ComparingFiles || m_modelList->mode() == Kompare::ComparingDirs);
+    if (m_saveDiff) m_saveDiff->setEnabled(m_modelList->mode() == KompareDiff2::ComparingFiles || m_modelList->mode() == KompareDiff2::ComparingDirs);
+    if (m_swap) m_swap->setEnabled(m_modelList->mode() == KompareDiff2::ComparingFiles || m_modelList->mode() == KompareDiff2::ComparingDirs);
+    m_diffRefresh->setEnabled(m_modelList->mode() == KompareDiff2::ComparingFiles || m_modelList->mode() == KompareDiff2::ComparingDirs);
     m_diffStats->setEnabled(m_modelList->modelCount() > 0);
     m_print->setEnabled(m_modelList->modelCount() > 0);          // If modellist has models then we have something to print, it's that simple.
     m_printPreview->setEnabled(m_modelList);
@@ -226,7 +217,7 @@ bool KomparePart::openDiff(const QUrl& url)
 {
     qCDebug(KOMPAREPART) << "Url = " << url.url();
 
-    m_info.mode = Kompare::ShowingDiff;
+    m_info.mode = KompareDiff2::ShowingDiff;
     m_info.source = url;
     bool result = false;
     fetchURL(url, true);
@@ -253,7 +244,7 @@ bool KomparePart::openDiff(const QString& diffOutput)
 {
     bool value = false;
 
-    m_info.mode = Kompare::ShowingDiff;
+    m_info.mode = KompareDiff2::ShowingDiff;
 
     Q_EMIT kompareInfo(&m_info);
 
@@ -424,7 +415,7 @@ void KomparePart::compare(const QUrl& source, const QUrl& destination)
 void KomparePart::compareFileString(const QUrl& sourceFile, const QString& destination)
 {
     //Set the modeto specify that the source is a file, and the destination is a string
-    m_info.mode = Kompare::ComparingFileString;
+    m_info.mode = KompareDiff2::ComparingFileString;
 
     m_info.source = sourceFile;
     m_info.localDestination = destination;
@@ -439,7 +430,7 @@ void KomparePart::compareFileString(const QUrl& sourceFile, const QString& desti
 void KomparePart::compareStringFile(const QString& source, const QUrl& destinationFile)
 {
     //Set the modeto specify that the source is a file, and the destination is a string
-    m_info.mode = Kompare::ComparingStringFile;
+    m_info.mode = KompareDiff2::ComparingStringFile;
 
     m_info.localSource = source;
     m_info.destination = destinationFile;
@@ -453,7 +444,7 @@ void KomparePart::compareStringFile(const QString& source, const QUrl& destinati
 
 void KomparePart::compareFiles(const QUrl& sourceFile, const QUrl& destinationFile)
 {
-    m_info.mode = Kompare::ComparingFiles;
+    m_info.mode = KompareDiff2::ComparingFiles;
 
     m_info.source = sourceFile;
     m_info.destination = destinationFile;
@@ -470,7 +461,7 @@ void KomparePart::compareFiles(const QUrl& sourceFile, const QUrl& destinationFi
 
 void KomparePart::compareDirs(const QUrl& sourceDirectory, const QUrl& destinationDirectory)
 {
-    m_info.mode = Kompare::ComparingDirs;
+    m_info.mode = KompareDiff2::ComparingDirs;
 
     m_info.source = sourceDirectory;
     m_info.destination = destinationDirectory;
@@ -498,7 +489,7 @@ void KomparePart::openFileAndDiff(const QUrl& file, const QUrl& diffFile)
 
     fetchURL(file, true);
     fetchURL(diffFile, false);
-    m_info.mode = Kompare::BlendingFile;
+    m_info.mode = KompareDiff2::BlendingFile;
 
     Q_EMIT kompareInfo(&m_info);
 
@@ -512,7 +503,7 @@ void KomparePart::openDirAndDiff(const QUrl& dir,  const QUrl& diffFile)
 
     fetchURL(dir, true);
     fetchURL(diffFile, false);
-    m_info.mode = Kompare::BlendingDir;
+    m_info.mode = KompareDiff2::BlendingDir;
 
     Q_EMIT kompareInfo(&m_info);
 
@@ -624,21 +615,21 @@ void KomparePart::slotPaintRequested(QPrinter* printer)
     qCDebug(KOMPAREPART) << "Done painting something...";
 }
 
-void KomparePart::slotSetStatus(enum Kompare::Status status)
+void KomparePart::slotSetStatus(enum KompareDiff2::Status status)
 {
     updateActions();
 
     switch (status) {
-    case Kompare::RunningDiff:
+    case KompareDiff2::RunningDiff:
         Q_EMIT setStatusBarText(i18nc("@info:status", "Running diff..."));
         break;
-    case Kompare::Parsing:
+    case KompareDiff2::Parsing:
         Q_EMIT setStatusBarText(i18nc("@info:status", "Parsing diff output..."));
         break;
-    case Kompare::FinishedParsing:
+    case KompareDiff2::FinishedParsing:
         updateStatus();
         break;
-    case Kompare::FinishedWritingDiff:
+    case KompareDiff2::FinishedWritingDiff:
         updateStatus();
         Q_EMIT diffURLChanged();
         break;
@@ -663,13 +654,13 @@ void KomparePart::updateCaption()
 
     switch (m_info.mode)
     {
-    case Kompare::ComparingFiles :
-    case Kompare::ComparingDirs :
-    case Kompare::BlendingFile :
-    case Kompare::BlendingDir :
+    case KompareDiff2::ComparingFiles :
+    case KompareDiff2::ComparingDirs :
+    case KompareDiff2::BlendingFile :
+    case KompareDiff2::BlendingDir :
         text = source + QLatin1String(" -- ") + destination; // no need to translate this " -- "
         break;
-    case Kompare::ShowingDiff :
+    case KompareDiff2::ShowingDiff :
         text = source;
         break;
     default:
@@ -688,25 +679,25 @@ void KomparePart::updateStatus()
 
     switch (m_info.mode)
     {
-    case Kompare::ComparingFiles :
+    case KompareDiff2::ComparingFiles :
         text = i18nc("@info:status", "Comparing file %1 with file %2" ,
                     source,
                     destination);
         break;
-    case Kompare::ComparingDirs :
+    case KompareDiff2::ComparingDirs :
         text = i18nc("@info:status", "Comparing files in %1 with files in %2" ,
                     source,
                     destination);
         break;
-    case Kompare::ShowingDiff :
+    case KompareDiff2::ShowingDiff :
         text = i18nc("@info:status", "Viewing diff output from %1", source);
         break;
-    case Kompare::BlendingFile :
+    case KompareDiff2::BlendingFile :
         text = i18nc("@info:status", "Blending diff output from %1 into file %2" ,
                     source,
                     destination);
         break;
-    case Kompare::BlendingDir :
+    case KompareDiff2::BlendingDir :
         text = i18nc("@info:status", "Blending diff output from %1 into folder %2" ,
                     m_info.source.toDisplayString(),
                     m_info.destination.toDisplayString());
@@ -725,18 +716,18 @@ void KomparePart::compareAndUpdateAll()
         switch (m_info.mode)
         {
         default:
-        case Kompare::UnknownMode:
+        case KompareDiff2::UnknownMode:
             m_modelList->compare();
             break;
 
-        case Kompare::ComparingStringFile:
-        case Kompare::ComparingFileString:
-        case Kompare::ComparingFiles:
-        case Kompare::ComparingDirs:
+        case KompareDiff2::ComparingStringFile:
+        case KompareDiff2::ComparingFileString:
+        case KompareDiff2::ComparingFiles:
+        case KompareDiff2::ComparingDirs:
             m_modelList->compare(m_info.mode);
             break;
 
-        case Kompare::BlendingFile:
+        case KompareDiff2::BlendingFile:
             m_modelList->openFileAndDiff();
             break;
         }
@@ -755,11 +746,7 @@ void KomparePart::slotSwap()
 {
     if (m_modelList->hasUnsavedChanges())
     {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         int query = KMessageBox::warningTwoActionsCancel
-#else
-        int query = KMessageBox::warningYesNoCancel
-#endif
                     (
                         widget(),
                         i18n("You have made changes to the destination file(s).\n"
@@ -769,18 +756,14 @@ void KomparePart::slotSwap()
                         KStandardGuiItem::discard()
                     );
 
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         if (query == KMessageBox::PrimaryAction)
-#else
-        if (query == KMessageBox::Yes)
-#endif
             m_modelList->saveAll();
 
         if (query == KMessageBox::Cancel)
             return; // Abort prematurely so no swapping
     }
 
-    // Swap the info in the Kompare::Info struct
+    // Swap the info in the KompareDiff2::Info struct
     m_info.swapSourceWithDestination();
 
     // Update window caption and statusbar text
@@ -794,11 +777,7 @@ void KomparePart::slotRefreshDiff()
 {
     if (m_modelList->hasUnsavedChanges())
     {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         int query = KMessageBox::warningTwoActionsCancel
-#else
-        int query = KMessageBox::warningYesNoCancel
-#endif
                     (
                         widget(),
                         i18n("You have made changes to the destination file(s).\n"
@@ -812,11 +791,7 @@ void KomparePart::slotRefreshDiff()
         if (query == KMessageBox::Cancel)
             return; // Abort prematurely so no refreshing
 
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         if (query == KMessageBox::PrimaryAction)
-#else
-        if (query == KMessageBox::Yes)
-#endif
             m_modelList->saveAll();
     }
 
@@ -845,22 +820,22 @@ void KomparePart::slotShowDiffstats()
     if (m_modelList->selectedModel())
     {
         switch (m_info.format) {
-        case Kompare::Unified :
+        case KompareDiff2::Unified :
             diffFormat = i18nc("@item diff format", "Unified");
             break;
-        case Kompare::Context :
+        case KompareDiff2::Context :
             diffFormat = i18nc("@item diff format", "Context");
             break;
-        case Kompare::RCS :
+        case KompareDiff2::RCS :
             diffFormat = i18nc("@item diff format", "RCS");
             break;
-        case Kompare::Ed :
+        case KompareDiff2::Ed :
             diffFormat = i18nc("@item diff format", "Ed");
             break;
-        case Kompare::Normal :
+        case KompareDiff2::Normal :
             diffFormat = i18nc("@item diff format", "Normal");
             break;
-        case Kompare::UnknownFormat :
+        case KompareDiff2::UnknownFormat :
         default:
             diffFormat = i18nc("@item diff format", "Unknown");
             break;
@@ -918,11 +893,7 @@ bool KomparePart::queryClose()
 {
     if (!m_modelList->hasUnsavedChanges()) return true;
 
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     int query = KMessageBox::warningTwoActionsCancel
-#else
-    int query = KMessageBox::warningYesNoCancel
-#endif
                 (
                     widget(),
                     i18n("You have made changes to the destination file(s).\n"
@@ -936,11 +907,7 @@ bool KomparePart::queryClose()
     if (query == KMessageBox::Cancel)
         return false;
 
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     if (query == KMessageBox::PrimaryAction)
-#else
-    if (query == KMessageBox::Yes)
-#endif
         return m_modelList->saveAll();
 
     return true;
